==> jAddo___2022-12-16_03-21-50.zip: faq.php <==
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<title>ORV HeadQuarters - FAQ</title>
	<meta name="description" content="ATV & SxS performance shop that offers customization, upgrades along with your everyday maintenance! 42 Union Street, Smiths Falls, ON, Canada K7A 5C4.">

	<meta name="format-detection" content="telephone=no">
	
	<!-- Fonts -->
	<link rel="preconnect" href="https://fonts.googleapis.com">
	<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
	<link href="https://fonts.googleapis.com/css2?family=Bebas+Neue&display=swap" rel="stylesheet">
	<link rel="stylesheet" href="https://use.typekit.net/ymo0arc.css">
	<link rel="stylesheet" type="text/css" href="assets/font/proxima-nova.css">

	<!-- Bootstrap CSS -->
	<link rel="stylesheet" type="text/css" href="assets/bootstrap/css/bootstrap.min.css">

    <!-- Isonax ICONS -->
	<link rel="stylesheet" href="assets/iconsax/style.css">
    <!-- FONTAWESOME ICONS -->
	<link rel="stylesheet" type="text/css" href="assets/font-awesome/css/all.css">
	<!-- Bootstrap ICONS -->
	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.9.1/font/bootstrap-icons.css">   

	<!-- Swiper CSS -->
	<link rel="stylesheet" href="assets/swiper/swiper-bundle.min.css">

	<!-- Tom Select CSS -->
	<link rel="stylesheet" href="assets/tom-select/tom-select.css">

	<!-- Bootstrap Plus CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/bootstrap-plus.css">
	<!-- CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/style.css">

</head>
<body class="bg-dark bg-noise text-white">
	<header>
		<a href="my-account.php" class="mobile-navbar d-block d-lg-none bg-gradient-dark border-bottom border-1 border-white border-opacity-05 rounded-bottom text-primary text-md text-600 lh-sm text-center text-decoration-none p-4">
			<i class="bi bi-arrow-left me-2"></i>
			BACK TO MY ACCOUNT
		</a>
		<?php include './src/navbar.php';?>		
	</header>

	<main>	
		<section class="section-faq pb-md-5 mb-md-5 pt-5 mt-lg-5 pt-lg-4">
			<div class="container">
				<div class="row justify-content-center text-center">
					<div class="col-12 col-md-10 col-xxl-8 text-center mb-5 pb-md-5">
						<h2 class="headline-2 text-800 lh-1 text-uppercase mb-3">CUSTOMER SERVICE</h2>
						<p class="text-xs lh-1_1 mb-md-2">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.</p>
					</div>
					<div class="col-12 col-md-10 mb-md-5 pb-3 pb-lg-5">
                        <div class="accordion accordion-flush pb-md-3" id="accordionFAQ">
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingOne">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseOne" aria-expanded="false" aria-controls="FAQ-collapseOne">
                                        1. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseOne" class="accordion-collapse collapse" aria-labelledby="FAQ-headingOne" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header rounded-3" id="FAQ-headingTwo">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseTwo" aria-expanded="false" aria-controls="FAQ-collapseTwo">
                                        2. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseTwo" class="accordion-collapse collapse" aria-labelledby="FAQ-headingTwo" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark  border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingThree">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseThree" aria-expanded="false" aria-controls="FAQ-collapseThree">
                                        3. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseThree" class="accordion-collapse collapse" aria-labelledby="FAQ-headingThree" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingFour">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseFour" aria-expanded="false" aria-controls="FAQ-collapseFour">
                                        4. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseFour" class="accordion-collapse collapse" aria-labelledby="FAQ-headingFour" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header rounded-3" id="FAQ-headingFive">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseFive" aria-expanded="false" aria-controls="FAQ-collapseFive">
                                        5. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseFive" class="accordion-collapse collapse" aria-labelledby="FAQ-headingFive" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark  border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingSix">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseSix" aria-expanded="false" aria-controls="FAQ-collapseSix">
                                        6. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseSix" class="accordion-collapse collapse" aria-labelledby="FAQ-headingSix" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark  border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingSeven">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseSeven" aria-expanded="false" aria-controls="FAQ-collapseSeven">
                                       7. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseSeven" class="accordion-collapse collapse" aria-labelledby="FAQ-headingSeven" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                        </div>					
					</div>
				</div>
                <div class="row justify-content-center mb-md-2 mb-xxl-4">
                    <div class="col-12 col-md-10 col-lg-4 mb-6 mb-lg-0 pb-2 pb-md-5 pb-lg-0">
                        <h5 class="headline-5 text-700 lh-1 pb-1 pb-lg-0 mb-2 mb-lg-4">1. Lorem ipsum dolor sit</h5>
                        <p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
                        </p>
                    </div>
                    <div class="col-12 col-md-10 col-lg-4 mb-6 mb-lg-0 pb-2 pb-md-5 pb-lg-0">
                        <h5 class="headline-5 text-700 lh-1 pb-1 pb-lg-0 mb-2 mb-lg-4">2. Lorem ipsum dolor sit</h5>
                        <p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
                        </p>
                    </div>
                    <div class="col-12 col-md-10 col-lg-4 mb-6 mb-lg-0 pb-2 pb-md-5 pb-lg-0">
                        <h5 class="headline-5 text-700 lh-1 pb-1 pb-lg-0 mb-2 mb-lg-4">3. Lorem ipsum dolor sit</h5>
                        <p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
                        </p>
                    </div>
                </div>			
			</div>
		</section>

        <?php include './src/section-contact.php';?>	
			
	</main>

	<?php include './src/footer.php';?>	
	<?php include './src/navbar-offcanvas-chat.php';?>
    <?php include './src/navbar-offcanvas-cart.php';?>
    <?php include './src/navbar-offcanvas-user-panel.php';?>
    <?php include './src/navbar-modal.php';?>

	<!-- Bootstrap JS -->	
	<script type="text/javascript" src="assets/bootstrap/js/bootstrap.bundle.min.js" async></script>

	<!-- Tom Select JS -->
	<script src="https://cdn.jsdelivr.net/npm/tom-select@2.1.0/dist/js/tom-select.complete.min.js"></script>

	<!-- Swiper JS -->
	<script src="assets/swiper/swiper-bundle.min.js" defer></script>
	<!-- JS -->
	<script type="text/javascript" src="assets/js/calender.js" defer></script>
	<script type="text/javascript" src="assets/js/script.js" defer></script>
</body>
</html>

==> jAddo___2022-12-16_03-24-21.zip: faq.php <==
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<title>ORV HeadQuarters - FAQ</title>
	<meta name="description" content="ATV & SxS performance shop that offers customization, upgrades along with your everyday maintenance! 42 Union Street, Smiths Falls, ON, Canada K7A 5C4.">

	<meta name="format-detection" content="telephone=no">
	
	<!-- Fonts -->
	<link rel="preconnect" href="https://fonts.googleapis.com">
	<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
	<link href="https://fonts.googleapis.com/css2?family=Bebas+Neue&display=swap" rel="stylesheet">
	<link rel="stylesheet" href="https://use.typekit.net/ymo0arc.css">
	<link rel="stylesheet" type="text/css" href="assets/font/proxima-nova.css">

	<!-- Bootstrap CSS -->
	<link rel="stylesheet" type="text/css" href="assets/bootstrap/css/bootstrap.min.css">

    <!-- Isonax ICONS -->
	<link rel="stylesheet" href="assets/iconsax/style.css">
    <!-- FONTAWESOME ICONS -->
	<link rel="stylesheet" type="text/css" href="assets/font-awesome/css/all.css">
	<!-- Bootstrap ICONS -->
	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.9.1/font/bootstrap-icons.css">   

	<!-- Swiper CSS -->
	<link rel="stylesheet" href="assets/swiper/swiper-bundle.min.css">

	<!-- Tom Select CSS -->
	<link rel="stylesheet" href="assets/tom-select/tom-select.css">

	<!-- Bootstrap Plus CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/bootstrap-plus.css">
	<!-- CSS -->
	<link rel="stylesheet" type="text/css" href="assets/css/style.css">

</head>
<body class="bg-dark bg-noise text-white">
	<header>
		<a href="my-account.php" class="mobile-navbar d-block d-lg-none bg-gradient-dark border-bottom border-1 border-white border-opacity-05 rounded-bottom text-primary text-md text-600 lh-sm text-center text-decoration-none p-4">
			<i class="bi bi-arrow-left me-2"></i>
			BACK TO MY ACCOUNT
		</a>
		<?php include './src/navbar.php';?>		
	</header>

	<main>	
		<section class="section-faq pb-md-5 mb-md-5 pt-5 mt-lg-5 pt-lg-4">
			<div class="container">
				<div class="row justify-content-center text-center">
					<div class="col-12 col-md-10 col-xxl-8 text-center mb-5 pb-md-5">
						<h2 class="headline-2 text-800 lh-1 text-uppercase mb-3">CUSTOMER SERVICE</h2>
						<p class="text-xs lh-1_1 mb-md-2">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.</p>
					</div>
					<div class="col-12 col-md-10 mb-md-5 pb-3 pb-lg-5">
                        <div class="accordion accordion-flush pb-md-3" id="accordionFAQ">
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingOne">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseOne" aria-expanded="false" aria-controls="FAQ-collapseOne">
                                        1. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseOne" class="accordion-collapse collapse" aria-labelledby="FAQ-headingOne" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header rounded-3" id="FAQ-headingTwo">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseTwo" aria-expanded="false" aria-controls="FAQ-collapseTwo">
                                        2. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseTwo" class="accordion-collapse collapse" aria-labelledby="FAQ-headingTwo" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark  border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingThree">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseThree" aria-expanded="false" aria-controls="FAQ-collapseThree">
                                        3. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseThree" class="accordion-collapse collapse" aria-labelledby="FAQ-headingThree" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingFour">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseFour" aria-expanded="false" aria-controls="FAQ-collapseFour">
                                        4. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseFour" class="accordion-collapse collapse" aria-labelledby="FAQ-headingFour" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark border-0 text-white">
                                <h2 class="accordion-header rounded-3" id="FAQ-headingFive">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseFive" aria-expanded="false" aria-controls="FAQ-collapseFive">
                                        5. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseFive" class="accordion-collapse collapse" aria-labelledby="FAQ-headingFive" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark  border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingSix">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseSix" aria-expanded="false" aria-controls="FAQ-collapseSix">
                                        6. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseSix" class="accordion-collapse collapse" aria-labelledby="FAQ-headingSix" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item mb-4 rounded-3 card-bg-dark  border-0 text-white">
                                <h2 class="accordion-header" id="FAQ-headingSeven">
                                    <button class="accordion-button collapsed bg-transparent text-white text-md lh-1 text-800 p-4" type="button" data-bs-toggle="collapse" data-bs-target="#FAQ-collapseSeven" aria-expanded="false" aria-controls="FAQ-collapseSeven">
                                       7. Can I return my product?
                                    </button>
                                </h2>
                                <div id="FAQ-collapseSeven" class="accordion-collapse collapse" aria-labelledby="FAQ-headingSeven" data-bs-parent="#accordionFAQ">
                                    <div class="accordion-body p-4 pt-0 text-start text-xs lh-1_1">
                                        <span class="text-700 d-block mb-2">Yes!</span>
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.
                                    </div>
                                </div>
                            </div>
                        </div>					
					</div>
				</div>
                <div class="row justify-content-center mb-md-2 mb-xxl-4">
                    <div class="col-12 col-md-10 col-lg-4 mb-6 mb-lg-0 pb-2 pb-md-5 pb-lg-0">
                        <h5 class="headline-5 headline-lg-5 text-lg-4 text-700 lh-1 pb-1 pb-lg-0 mb-2 mb-lg-4">1. Lorem ipsum dolor sit</h5>
                        <p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
                        </p>
                    </div>
                    <div class="col-12 col-md-10 col-lg-4 mb-6 mb-lg-0 pb-2 pb-md-5 pb-lg-0">
                        <h5 class="headline-5 headline-lg-5 text-lg-4 text-700 lh-1 pb-1 pb-lg-0 mb-2 mb-lg-4">2. Lorem ipsum dolor sit</h5>
                        <p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
                        </p>
                    </div>
                    <div class="col-12 col-md-10 col-lg-4 mb-6 mb-lg-0 pb-2 pb-md-5 pb-lg-0">
                        <h5 class="headline-5 headline-lg-5 text-700 lh-1 pb-1 pb-lg-0 mb-2 mb-lg-4">3. Lorem ipsum dolor sit</h5>
                        <p class="text-xs lh-1_1 mb-0">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
                        </p>
                    </div>
                </div>			
			</div>
		</section>

        <?php include './src/section-contact.php';?>	
			
	</main>

	<?php include './src/footer.php';?>	
	<?php include './src/navbar-offcanvas-chat.php';?>
    <?php include './src/navbar-offcanvas-cart.php';?>
    <?php include './src/navbar-offcanvas-user-panel.php';?>
    <?php include './src/navbar-modal.php';?>

	<!-- Bootstrap JS -->	
	<script type="text/javascript" src="assets/bootstrap/js/bootstrap.bundle.min.js" async></script>

	<!-- Tom Select JS -->
	<script src="https://cdn.jsdelivr.net/npm/tom-select@2.1.0/dist/js/tom-select.complete.min.js"></script>

	<!-- Swiper JS -->
	<script src="assets/swiper/swiper-bundle.min.js" defer></script>
	<!-- JS -->
	<script type="text/javascript" src="assets/js/calender.js" defer></script>
	<script type="text/javascript" src="assets/js/script.js" defer></script>
</body>
</html>
